@@ -1,26 +1,26 @@
 <?php
 
-$EM_CONF['sg_estate_base'] = array(
+$EM_CONF['sg_estate_base'] = [
     'title' => 'sg.estate - Base',
     'description' => 'Base Extension (Search, List, Detail and Contact) for sg_estate',
     'category' => 'plugin',
     'author' => 'Marc Saleiko, Daniel Hoffmann',
     'author_email' => 'saleiko@smply.gd, hoffmann@smply.gd',
     'author_company' => 'smply.gd GmbH',
-    'state' => 'beta',
+    'state' => 'stable',
     'internal' => '',
     'uploadfolder' => '0',
     'clearCacheOnLoad' => 0,
-    'version' => '10.3.0',
-    'constraints' => array(
-        'depends' => array(
+    'version' => '10.20.1',
+    'constraints' => [
+        'depends' => [
             'typo3' => '10.4.4-10.4.99',
             'sg_estate_core' => '>=10.5.0',
             'vhs' => '>=6.0.3'
-        ),
-        'conflicts' => array(
-        ),
-        'suggests' => array(
-        ),
-    ),
-);
\ No newline at end of file
+        ],
+        'conflicts' => [
+        ],
+        'suggests' => [
+        ],
+    ],
+];
